@@ -32,25 +32,33 @@ class ConstantDict(object):
 
 
 class MsgFields(ConstantDict):
-    ASNIP = "asnip"
-    ASN = "asn"
-    AS_NAME = "asname"
-    AS_CIDR = "ascidr"
+    ABUSE_EMAIL = "abuseemail"
     ARTIFACT = "artifact"
+    ASN = "asn"
+    ASNIP = "asnip"
+    AS_CC = "asncc"
+    AS_CIDR = "ascidr"
+    AS_NAME = "asname"
+    AS_UPDATE_DATE = "asupdatedate"
     CIDR = "cidr"
     COUNTRY_CODE = "cc"
-    LAT = "lat"
-    LONG = "long"
     DOMAIN = "domain"
     GEOIP = "geoip"
     HOSTNAME = "hostname"
     HTTP_STATUS = "httpstatus"
+    HTTP_REDIR = "httpredir"
+    HTTP_HEADERS = "httpheaders"
     IP = "ip"
     IPSET = "ipset"
-    NET_CIDR = "cidr"
+    LAT = "lat"
+    LONG = "long"
+    NET_CC = "netcc"
+    NET_CIDR = "netcidr"
     NET_DESC = "netdesc"
-    NET_NAME = "netcidr"
+    NET_NAME = "netname"
+    NET_UPDATE_DATE = "netupdatedate"
     PATH = "path"
+    PHYSICAL_ADDRESS = "phyaddr"
     SCREENSHOT = "screenshot"
     SPIDER = "spider"
     URL = "url"
