@@ -78,12 +78,18 @@ AsnipSchema = build_schema({
                 ipv4v6re: {
                     "type": "object",
                     "properties": {
+                        F.ABUSE_EMAIL: {"type": ["string", "null"]},
                         F.ASN: {"type": ["number", "null"]},
-                        F.AS_NAME: {"type": ["string", "null"]},
+                        F.AS_CC: {"type": ["string", "null"]},
                         F.AS_CIDR: {"type": ["string", "null"]},
-                        F.NET_NAME: {"type": ["string", "null"]},
-                        F.NET_DESC: {"type": ["string", "null"]},
+                        F.AS_NAME: {"type": ["string", "null"]},
+                        F.AS_UPDATE_DATE: {"type": ["string", "null"]},
+                        F.NET_CC: {"type": ["string", "null"]},
                         F.NET_CIDR: {"type": ["string", "null"]},
+                        F.NET_DESC: {"type": ["string", "null"]},
+                        F.NET_NAME: {"type": ["string", "null"]},
+                        F.NET_UPDATE_DATE: {"type": ["string", "null"]},
+                        F.PHYSICAL_ADDRESS: {"type": ["string", "null"]},
                     },
                 }
             },
@@ -104,6 +110,14 @@ HostnameSchema = build_schema({
     }
 })
 
+HttpstatusSchema = build_schema({
+    "properties": {
+        F.HTTP_STATUS: {"type": ["number", "null"]},
+        F.HTTP_REDIR: {"type": ["string", "null"]},
+        F.HTTP_HEADERS: {"type": ["object", "null"]},
+    }
+})
+
 IpSingleSchema = build_schema({
     "properties": {
         F.IP: {
@@ -143,12 +157,6 @@ GeoipSchema = build_schema({
     }
 })
 
-HttpstatusSchema = build_schema({
-    "properties": {
-        F.HTTP_STATUS: {"type": ["number", "null"]},
-    }
-})
-
 UrlSchema = build_schema({
     "properties": {
         F.URL: {"type": "string"},
